import { Entity, PrimaryGeneratedColumn, Column } from "typeorm";
import {
  IsInt,
  IsNotEmpty,
  IsOptional,
  IsPositive,
  IsString,
} from "class-validator";

/**
 * @classdesc Defines a track of given length.
 * @property {number} id - Autogenerated unique id
 * @property {string} name - The track's name
 * @property {number} lenth - The track's length in meters
*/
@Entity()
export class Track {
  @PrimaryGeneratedColumn()
  @IsOptional()
  @IsInt()
  id: number;

  @Column()
  @IsString()
  @IsNotEmpty()
  name: string;

  @Column()
  @IsInt()
  @IsPositive()
  length: number;
}
